@@ -1,4 +1,4 @@
-from .printer import Printer
+from .printer import Flattener, Printer
 from .text import Text
 from .table import Table
 from .pretty import pretty
@@ -14,10 +14,8 @@ class PrettyException(Exception):
 
 
     def __str__(self):
-        for line in Printer(ascii=True, color=False).each_line(pretty(self)):
-            return str(line)
-        else:
-            return repr(self)
+        w = self.msg if hasattr(self, 'msg') else pretty(self)
+        return Flattener(ascii=True, color=False).to_str(w).rstrip()
 
 
     def __repr__(self):
@@ -26,10 +24,12 @@ class PrettyException(Exception):
         return s+ ', '.join(args) + ')'
 
 
-    def pretty(self):
-        t = Text(self.__class__.__name__)
-        if self.__dict__:
-            t('\v',pretty(self.__dict__))
-        return t
-
-
+    def __pretty__(self, **kwargs):
+        p = Printer()
+        if hasattr(self, 'msg'):
+            p(self.msg)
+        else:
+            p(self.__class__.__name__)
+        vars = {k:v for k,v in self.__dict__.items() if k != 'msg'}
+        if vars: p.pretty(vars, pad=-1, **kwargs)
+        return p
